==> jsbos-common-2024.12.dev.005-sources.jar: com/bringspring/common/config/constant/ConfigConst.java <==
package com.bringspring.common.config.constant;

/**
 * 配置静态参数
 *
 * @author RKKJ开发平台组 YanYu
 * @version V1.0.0
 * @copyright 荣科科技股份有限公司
 * @date 2021/12/15
 */
public class ConfigConst {


    /**
     * 前端附件文件夹
     */
    public final static String WEB_ANNEX_FOLDER = "WebAnnexFile";
    /**
     * 前端附件文件夹
     */
    public final static String LICENSE_FILE_PATH = "License";

    /**
     * 临时文件夹
     */
    public final static String TEMPORARY_FOLDER = "TemporaryFile";

    /**
     * 系统文件夹
     */
    public final static String SYSTEM_FOLDER = "SystemFile";

    /**
     * 文件模板文件夹
     */
    public final static String TEMPLATE_FOLDER = "TemplateFile";

    /**
     * 邮件文件夹
     */
    public final static String EMAIL_FOLDER = "EmailFile";

    /**
     * 文档管理文件夹
     */
    public final static String DOCUMENT_FOLDER = "DocumentFile";

    /**
     * 压缩文件夹下载路径
     */
    public final static String DOCUMENT_ZIP = "temporaryZip";

    /**
     * 文档预览文件夹
     */
    public final static String DOCUMENT_PREVIEW_FOLDER = "DocumentPreview";

    /**
     * 用户头像文件夹
     */
    public final static String USER_AVATAR_FOLDER = "UserAvatar";

    /**
     * IM聊天图片+语音存储文件夹
     */
    public final static String IM_CONTENT_FOLDER = "IMContentFile";

    /**
     * 代码模板文件夹
     */
    public final static String TEMPLATE_CODE_FOLDER = "TemplateCode";

    /**
     * 大屏图片文件夹
     */
    public final static String BI_VISUAL_FOLDER = "BiVisualPath";

    /**
     * 数据库备份文件夹
     */
    public final static String DATA_BACKUP_FOLDER = "DataBackupFile";

    /**
     * 前端模板文件夹
     */
    public final static String CODE_TEMP_FOLDER = "CodeTemp";

    /**
     * 边缘计算文件存储
     */
    public final static String DOCUMENT_ECBP = "DocumentEcbp";

    /**
     * 物联网解析包
     */
    public final static String IOT_ANALYSIS = "iotAnalysis";
}

==> jsbos-common-2025.12.dev-sources.jar: com/bringspring/common/config/constant/ConfigConst.java <==
package com.bringspring.common.config.constant;

/**
 * 配置静态参数
 *
 * @author RKKJ开发平台组 YanYu
 * @version V1.0.0
 * @copyright 荣科科技股份有限公司
 * @date 2021/12/15
 */
public class ConfigConst {


    /**
     * 前端附件文件夹
     */
    public final static String WEB_ANNEX_FOLDER = "WebAnnexFile";

    /*
     * 费控原始附件文件夹
     */
    public final static String ECS_ORIGINAL_FOLDER = "EcsOriginalFile";

    /**
     * 费控报销单附件文件夹
     */

    public final static String ECS_REIMBURSEMENT_FOLDER = "EcsReimbursementFile";
    /**
     * 前端附件文件夹
     */
    public final static String LICENSE_FILE_PATH = "License";

    /**
     * 临时文件夹
     */
    public final static String TEMPORARY_FOLDER = "TemporaryFile";

    /**
     * 系统文件夹
     */
    public final static String SYSTEM_FOLDER = "SystemFile";

    /**
     * 文件模板文件夹
     */
    public final static String TEMPLATE_FOLDER = "TemplateFile";

    /**
     * 邮件文件夹
     */
    public final static String EMAIL_FOLDER = "EmailFile";

    /**
     * 文档管理文件夹
     */
    public final static String DOCUMENT_FOLDER = "DocumentFile";

    /**
     * 压缩文件夹下载路径
     */
    public final static String DOCUMENT_ZIP = "temporaryZip";

    /**
     * 文档预览文件夹
     */
    public final static String DOCUMENT_PREVIEW_FOLDER = "DocumentPreview";

    /**
     * 用户头像文件夹
     */
    public final static String USER_AVATAR_FOLDER = "UserAvatar";

    /**
     * IM聊天图片+语音存储文件夹
     */
    public final static String IM_CONTENT_FOLDER = "IMContentFile";

    /**
     * 代码模板文件夹
     */
    public final static String TEMPLATE_CODE_FOLDER = "TemplateCode";

    /**
     * 大屏图片文件夹
     */
    public final static String BI_VISUAL_FOLDER = "BiVisualPath";

    /**
     * 数据库备份文件夹
     */
    public final static String DATA_BACKUP_FOLDER = "DataBackupFile";

    /**
     * 前端模板文件夹
     */
    public final static String CODE_TEMP_FOLDER = "CodeTemp";

    /**
     * 边缘计算文件存储
     */
    public final static String DOCUMENT_ECBP = "DocumentEcbp";

    /**
     * 物联网解析包
     */
    public final static String IOT_ANALYSIS = "iotAnalysis";

    /**
     * vue3代码模板文件夹
     */
    public final static String TEMPLATEVUE3_CODE_FOLDER = "TemplateCodeVue3";

    /**
     * 多语言文件夹
     */
    public final static String BASE_LANGUAGE = "Language";

    /**
     * ZIP打包文件夹
     */
    public final static String ZIP_PACKAGE_FOLDER = "ZipFileTemp";
}
